@@ -176,7 +176,7 @@ static const char *arg(csh *handle, cs_insn *insn, char *buf, int n) {
 
 #define ARG(x) (*str[x] != 0) ? str[x] : arg(handle, insn, str[x], x)
 
-static int analop_esil(RzAnalysis *a, RzAnalysisOp *op, ut64 addr, const ut8 *buf, int len, csh *handle, cs_insn *insn) {
+static int analyze_op_esil(RzAnalysis *a, RzAnalysisOp *op, ut64 addr, const ut8 *buf, int len, csh *handle, cs_insn *insn) {
 	char str[8][32] = { { 0 } };
 	int i;
 
@@ -315,7 +315,7 @@ static void set_opdir(RzAnalysisOp *op) {
 	}
 }
 
-static int analop(RzAnalysis *analysis, RzAnalysisOp *op, ut64 addr, const ut8 *buf, int len, RzAnalysisOpMask mask) {
+static int analyze_op(RzAnalysis *analysis, RzAnalysisOp *op, ut64 addr, const ut8 *buf, int len, RzAnalysisOpMask mask) {
 	int n, ret, opsize = -1;
 	static csh hndl = 0;
 	static int omode = -1;
@@ -380,7 +380,7 @@ beach:
 		opex(&op->opex, hndl, insn);
 	}
 	if (mask & RZ_ANALYSIS_OP_MASK_ESIL) {
-		if (analop_esil(analysis, op, addr, buf, len, &hndl, insn) != 0) {
+		if (analyze_op_esil(analysis, op, addr, buf, len, &hndl, insn) != 0) {
 			rz_strbuf_fini(&op->esil);
 		}
 	}
@@ -601,7 +601,7 @@ RzAnalysisPlugin rz_analysis_plugin_riscv_cs = {
 	.get_reg_profile = get_reg_profile,
 	.archinfo = archinfo,
 	.bits = 32 | 64,
-	.op = &analop,
+	.op = &analyze_op,
 };
 
 #ifndef RZ_PLUGIN_INCORE
