@@ -5,9 +5,9 @@
  * A plugin allowing to run "scripts" written in C language
  */
 
-#include "rz_lib.h"
-#include "rz_core.h"
-#include "rz_lang.h"
+#include <rz_lib.h>
+#include <rz_core.h>
+#include <rz_lang.h>
 
 #if __UNIX__
 static int ac = 0;
@@ -74,10 +74,10 @@ static int lang_c_file(RzLang *lang, const char *file) {
 	}
 	free(buf);
 	buf = rz_str_newf("%s/lib%s." RZ_LIB_EXT, libpath, libname);
-	lib = rz_lib_dl_open(buf);
+	lib = rz_sys_dlopen(buf);
 	if (lib) {
 		void (*fcn)(RzCore *, int argc, const char **argv);
-		fcn = rz_lib_dl_sym(lib, "entry");
+		fcn = rz_sys_dlsym(lib, "entry");
 		if (fcn) {
 			fcn(lang->user, ac, av);
 			ac = 0;
@@ -85,7 +85,7 @@ static int lang_c_file(RzLang *lang, const char *file) {
 		} else {
 			eprintf("Cannot find 'entry' symbol in library\n");
 		}
-		rz_lib_dl_close(lib);
+		rz_sys_dlclose(lib);
 	} else {
 		eprintf("Cannot open library\n");
 	}
@@ -113,7 +113,7 @@ static int lang_c_run(RzLang *lang, const char *code, int len) {
 	return true;
 }
 
-static RzLangPlugin rz_lang_plugin_c = {
+RzLangPlugin rz_lang_plugin_c = {
 	.name = "c",
 	.ext = "c",
 	.desc = "C language extension",
@@ -123,6 +123,15 @@ static RzLangPlugin rz_lang_plugin_c = {
 	.run_file = (void *)lang_c_file,
 	.set_argv = (void *)lang_c_set_argv,
 };
+
+#ifndef RZ_PLUGIN_INCORE
+RZ_API RzLibStruct rizin_plugin = {
+	.type = RZ_LIB_TYPE_LANG,
+	.data = &rz_lang_plugin_c,
+	.version = RZ_VERSION
+};
+#endif
+
 #else
 #ifdef _MSC_VER
 #pragma message("Warning: C RzLangPlugin is not implemented on this platform")
