@@ -118,40 +118,61 @@ bool test_map(void) {
 	mu_assert_eq(map->itv.addr, 0x403, "map addr");
 	mu_assert_eq(map->itv.size, 1, "map size");
 	mu_assert_eq(map->perm, RZ_PERM_R, "io map perm");
+	RzCoreIOMapInfo *info = map->user;
+	mu_assert_notnull(info, "map info");
+	mu_assert_ptreq(info->cf, f, "map info corefile");
+	mu_assert_eq(info->perm_orig, RZ_PERM_R, "map info perm");
+
 	map = rz_pvector_at(&core->io->maps, 5);
 	mu_assert_streq(map->name, "vmap.vfile map with zeroes", "io map name");
 	mu_assert_eq(map->delta, 0, "map delta");
 	mu_assert_eq(map->itv.addr, 0x400, "map addr");
 	mu_assert_eq(map->itv.size, 3, "map size");
 	mu_assert_eq(map->perm, RZ_PERM_R, "io map perm");
+
 	map = rz_pvector_at(&core->io->maps, 3);
 	mu_assert_streq(map->name, "vmap.vfile map", "io map name");
 	mu_assert_eq(map->delta, 4, "map delta");
 	mu_assert_eq(map->itv.addr, 0x300, "map addr");
 	mu_assert_eq(map->itv.size, 4, "map size");
 	mu_assert_eq(map->perm, RZ_PERM_RWX, "io map perm");
+	info = map->user;
+	mu_assert_notnull(info, "map info");
+	mu_assert_ptreq(info->cf, f, "map info corefile");
+	mu_assert_eq(info->perm_orig, RZ_PERM_RWX, "map info perm");
+
 	map = rz_pvector_at(&core->io->maps, 1);
 	mu_assert_streq(map->name, "mmap.direct map with zeroes", "io map name");
 	mu_assert_eq(map->delta, 0, "map delta");
 	mu_assert_eq(map->itv.addr, 0x202, "map addr");
 	mu_assert_eq(map->itv.size, 0x2e, "map size");
 	mu_assert_eq(map->perm, RZ_PERM_R, "io map perm");
+	info = map->user;
+	mu_assert_notnull(info, "map info");
+	mu_assert_ptreq(info->cf, f, "map info corefile");
+	mu_assert_eq(info->perm_orig, RZ_PERM_R, "map info perm");
+
 	map = rz_pvector_at(&core->io->maps, 2);
 	mu_assert_streq(map->name, "fmap.direct map with zeroes", "io map name");
 	mu_assert_eq(map->delta, 2, "map delta");
 	mu_assert_eq(map->itv.addr, 0x200, "map addr");
 	mu_assert_eq(map->itv.size, 2, "map size");
 	mu_assert_eq(map->perm, RZ_PERM_R, "io map perm");
+
 	map = rz_pvector_at(&core->io->maps, 0);
 	mu_assert_streq(map->name, "fmap.direct map", "io map name");
 	mu_assert_eq(map->delta, 2, "map delta");
 	mu_assert_eq(map->itv.addr, 0x100, "map addr");
 	mu_assert_eq(map->itv.size, 2, "map size");
 	mu_assert_eq(map->perm, RZ_PERM_RX, "io map perm");
+	info = map->user;
+	mu_assert_notnull(info, "map info");
+	mu_assert_ptreq(info->cf, f, "map info corefile");
+	mu_assert_eq(info->perm_orig, RZ_PERM_RX, "map info perm");
 
 	ut8 buf[8];
 	r = rz_io_read_at(core->io, 0, buf, sizeof(buf));
-	mu_assert_true(r, "io read");
+	mu_assert_false(r, "io read");
 	mu_assert_memeq(buf, (const ut8 *)"\xff\xff\xff\xff\xff\xff\xff\xff", 8, "unmapped read");
 	r = rz_io_read_at(core->io, 0xfe, buf, sizeof(buf));
 	mu_assert_true(r, "io read");
@@ -232,10 +253,10 @@ bool test_cfile_close(void) {
 
 	ut8 buf[8];
 	r = rz_io_read_at(core->io, 0xfe, buf, sizeof(buf));
-	mu_assert_true(r, "io read");
+	mu_assert_false(r, "io read");
 	mu_assert_memeq(buf, (const ut8 *)"\xff\xff\xff\xff\xff\xff\xff\xff", 8, "direct map read after close");
 	r = rz_io_read_at(core->io, 0x22e, buf, sizeof(buf));
-	mu_assert_true(r, "io read");
+	mu_assert_false(r, "io read");
 	mu_assert_memeq(buf, (const ut8 *)"\xff\xff\xff\xff\xff\xff\xff\xff", 8, "direct map read with zeroes end after close");
 
 	rz_core_free(core);
@@ -477,7 +498,7 @@ bool test_cfile_close_manual_vfile_fd(void) {
 	mu_assert_eq(rz_pvector_len(&core->io->maps), 0, "io maps count");
 
 	r = rz_io_read_at(core->io, 0x8000, buf, sizeof(buf));
-	mu_assert_true(r, "io read");
+	mu_assert_false(r, "io read");
 	mu_assert_memeq(buf, (const ut8 *)"\xff\xff\xff\xff\xff\xff\xff\xff", 8, "manual vfile map read");
 
 	rz_core_free(core);
@@ -517,7 +538,7 @@ bool test_cfile_close_manual_vfile_map(void) {
 	// now everything should be gone, including the vfile map which indirectly pointed into the core file's vfile fd
 	mu_assert_eq(rz_pvector_len(&core->io->maps), 0, "io maps count");
 	r = rz_io_read_at(core->io, 0x8000, buf, sizeof(buf));
-	mu_assert_true(r, "io read");
+	mu_assert_false(r, "io read");
 	mu_assert_memeq(buf, (const ut8 *)"\xff\xff\xff\xff\xff\xff\xff\xff", 8, "manual vfile map read");
 
 	rz_core_free(core);
